@@ -26,6 +26,9 @@ pub use ockam_executor::tokio;
 #[cfg(feature = "std")]
 pub use tokio;
 
+#[cfg(test)]
+mod tests;
+
 /// Async Mutex and RwLock
 pub mod compat;
 
@@ -34,6 +37,7 @@ mod context;
 mod error;
 mod executor;
 mod handle;
+mod heartbeat;
 mod messages;
 mod node;
 mod parser;
@@ -44,6 +48,7 @@ pub use cancel::*;
 pub use context::*;
 pub use executor::*;
 pub use handle::*;
+pub use heartbeat::*;
 pub use messages::*;
 
 pub use node::{start_node, NullWorker};
